@@ -60,7 +60,7 @@ static XrmOptionDescRec opts[] =
 
 static argtype vars[] =
 {
-        {(caddr_t *) & trackmouse, (char *) "trackmouse", (char *) "TrackMouse", (char *) DEF_TRACKMOUSE, t_Bool}
+        {(void *) & trackmouse, (char *) "trackmouse", (char *) "TrackMouse", (char *) DEF_TRACKMOUSE, t_Bool}
 };
 
 static OptionStruct desc[] =
@@ -222,17 +222,6 @@ init_swarm(ModeInfo * mi)
 	XDefineCursor(display, window, sp->cursor);
 
 	MI_CLEARWINDOW(mi);
-	if (!MI_IS_ICONIC(mi)) {
-		/* clip to size of screen (for broken Xservers) */
-		XRectangle cliprect[1];
-
-		cliprect[0].x = 0;
-		cliprect[0].y = 0;
-		cliprect[0].width = MI_WIDTH(mi);
-		cliprect[0].height = MI_HEIGHT(mi);
-		XSetClipRectangles(MI_DISPLAY(mi), MI_GC(mi), 0, 0,
-			cliprect, 1, Unsorted);
-	}
 
 	/* Allocate memory. */
 
@@ -351,7 +340,7 @@ draw_swarm(ModeInfo * mi)
 	}
 	/* <=- Bees -=> */
 	sp->tick = ++(sp->tick) % (sp->taillen);
-	prev = (sp->tick) ? sp->tick - 1 : sp->taillen - 1; 
+	prev = (sp->tick) ? sp->tick - 1 : sp->taillen - 1;
 	if (sp->tick == sp->taillen - 1)
 		sp->rolloverflag = 1;
 	for (b = 0; b < sp->beecount; b++) {
@@ -376,7 +365,7 @@ draw_swarm(ModeInfo * mi)
 		/* Move */
 		X(sp->tick, b) = X(prev, b) + sp->xv[b];
 		Y(sp->tick, b) = Y(prev, b) + sp->yv[b];
- 
+
 		/* Fill the segment lists. */
 		sp->segs[b].x1 = (short) X(sp->tick, b);
 		sp->segs[b].y1 = (short) Y(sp->tick, b);
@@ -416,7 +405,6 @@ release_swarm(ModeInfo * mi)
 		free(swarms);
 		swarms = (swarmstruct *) NULL;
 	}
-	XSetClipMask(MI_DISPLAY(mi), MI_GC(mi), None);
 }
 
 void
