@@ -56,11 +56,11 @@ extern Bool grabmouse;
 extern Bool nolock;
 extern char *cpasswd;
 
-#ifdef PAM
+#ifdef USE_PAM
 #include <X11/Xlib.h>
 #endif
 
-#ifdef __CYGWIN__
+#if defined(__CYGWIN__) || defined(SOLARIS2)
 #include <crypt.h>
 #endif
 
@@ -273,7 +273,7 @@ char        user[PASSLENGTH];
 char        global_user[PASSLENGTH];
 #endif
 
-#ifdef PAM
+#ifdef USE_PAM
 
 /* used to pass the password to the conversation function */
 static char *PAM_password;
@@ -285,10 +285,13 @@ static char *PAM_password;
  */
 
 int
-PAM_conv(int num_msg, 
-	 const struct pam_message **msg,
-	 struct pam_response **resp,
-	 void *appdata_ptr)
+PAM_conv(int num_msg,
+#ifndef SOLARIS2
+		const
+#endif
+		struct pam_message **msg,
+		struct pam_response **resp,
+		void *appdata_ptr)
 {
 	int         replies = 0;
 	struct pam_response *reply = NULL;
@@ -308,7 +311,7 @@ PAM_conv(int num_msg,
   			        PAM_putText( msg[replies], &reply[replies], True );
 #ifdef DEBUG
 			        (void) printf( "Back From PAM_putText: PAM_PROMPT_ECHO_ON\n" );
-			        (void) printf( "Response is: (%s)\n, Return Code is: (%d)\n", 
+			        (void) printf( "Response is: (%s)\n, Return Code is: (%d)\n",
 					 reply[replies].resp, reply[replies].resp_retcode );
 #endif
 				/* PAM frees resp */
@@ -325,7 +328,7 @@ PAM_conv(int num_msg,
 			  }
 #ifdef DEBUG
 			        (void) printf( "Back From PAM_putText: PAM_PROMPT_ECHO_OFF\n" );
-			        (void) printf( "Response is: (%s)\n, Return Code is: (%d)\n", 
+			        (void) printf( "Response is: (%s)\n, Return Code is: (%d)\n",
 					 reply[replies].resp, reply[replies].resp_retcode );
 #endif
 				/* PAM frees resp */
@@ -342,7 +345,7 @@ PAM_conv(int num_msg,
 			  }
 #ifdef DEBUG
 			        (void) printf( "Back From PAM_putText: PAM_PROMPT_ECHO_ON\n" );
-			        (void) printf( "Response is: (%s)\n, Return Code is: (%d)\n", 
+			        (void) printf( "Response is: (%s)\n, Return Code is: (%d)\n",
 					 reply[replies].resp, reply[replies].resp_retcode );
 #endif
 				/* PAM frees resp */
@@ -359,7 +362,7 @@ PAM_conv(int num_msg,
 			  }
 #ifdef DEBUG
 			        (void) printf( "Back From PAM_putText: PAM_PROMPT_ECHO_ON\n" );
-			        (void) printf( "Response is: (%s)\n, Return Code is: (%d)\n", 
+			        (void) printf( "Response is: (%s)\n, Return Code is: (%d)\n",
 					 reply[replies].resp, reply[replies].resp_retcode );
 #endif
 				break;
@@ -379,9 +382,9 @@ static const struct pam_conv PAM_conversation =
 	NULL
 };
 
-#endif /* PAM */
+#endif /* USE_PAM */
 
-#if !defined( ultrix ) && !defined( PAM )
+#if !defined( ultrix ) && !defined( USE_PAM )
 static char userpass[PASSLENGTH];
 static char rootpass[PASSLENGTH];
 #ifdef USE_XLOCK_GROUP
@@ -395,7 +398,7 @@ static int checkGroupXlockPasswds(char *buffer);
 static char root[] = ROOT;
 
 #endif
-#endif /* !ultrix && !PAM */
+#endif /* !ultrix && !USE_PAM */
 
 #ifdef DCE_PASSWD
 static int  usernet, rootnet;
@@ -443,7 +446,7 @@ static int	run_helper(const char *user, const char *pass);
 static struct passwd *
 my_passwd_entry(void)
 {
-	int         uid;
+	int uid;
 	struct passwd *pw;
 
 #ifdef HAVE_SHADOW
@@ -462,7 +465,7 @@ my_passwd_entry(void)
 			logname = getenv("USER");
 		if (logname != NULL) {
 			pw = getpwnam(logname);
-			if (pw && (pw->pw_uid != uid))
+			if (pw && ((int) pw->pw_uid != uid))
 				pw = 0;
 		}
 	}
@@ -472,7 +475,7 @@ my_passwd_entry(void)
 	if (!pw)
 		return (pw);
 #ifdef HAVE_SHADOW
-/*- 
+/*-
  * PURIFY on Solaris 2 reports a 1024 byte memory leak on the following line
  * if using NIS compatibility mode, and is internal to libc.so */
 	if ((spw = getspnam(pw->pw_name)) != NULL) {
@@ -768,7 +771,7 @@ gpass(void)
 
 #endif /* USE_XLOCKRC || FALLBACK_XLOCKRC */
 
-#if !defined( ultrix ) && !defined( DCE_PASSWD ) && !defined( BSD_AUTH )  && !defined ( PAM )
+#if !defined( ultrix ) && !defined( DCE_PASSWD ) && !defined( BSD_AUTH )  && !defined ( USE_PAM )
 #ifndef USE_XLOCKRC
 
 #if defined( HAVE_SHADOW ) && !defined( AFS ) && !defined( SIA )
@@ -1066,7 +1069,7 @@ getCryptedRootPasswd(void)
 #endif /* !VMS */
 }
 
-#endif /* !ultrix && !DCE_PASSWD && !BSD_AUTH && !PAM */
+#endif /* !ultrix && !DCE_PASSWD && !BSD_AUTH && !USE_PAM */
 
 
 #ifdef GLOBAL_UNLOCK
@@ -1088,7 +1091,7 @@ checkUser(char *buffer)
 		(void) strcpy(userpass, "*");
 	else {
 #ifdef HAVE_SHADOW
-/*- 
+/*-
  * PURIFY on Solaris 2 reports a 1024 byte memory leak on the following line
  * if using NIS compatibility mode, and is internal to libc.so */
 		if ((spw = getspnam(pw->pw_name)) != NULL) {
@@ -1161,7 +1164,7 @@ checkPasswd(char *buffer)
 		done = !strcmp(rootpass, crypt(buffer, rootpass));
 #else /* !DCE_PASSWD */
 
-#ifdef PAM
+#ifdef USE_PAM
 /*-
  * Use PAM to do authentication.  No session logging, only authentication.
  * Bail out if there are any errors.
@@ -1213,7 +1216,7 @@ checkPasswd(char *buffer)
 	/* If this point is reached, the user has been authenticated. */
 	done = True;
 
-#else /* !PAM */
+#else /* !USE_PAM */
 
 #ifdef ultrix
 
@@ -1390,7 +1393,7 @@ checkPasswd(char *buffer)
 		!strcmp((char *) crypt(buffer, rootpass), rootpass)
 #endif
 	) {
-		done = True;	
+		done = True;
 		if (!(rootpass && *buffer))
 			/*
 			 * root has no password, don't let him in...
@@ -1408,7 +1411,7 @@ checkPasswd(char *buffer)
 #endif
 #endif /* !BSD_AUTH */
 #endif /* !ultrix */
-#endif /* !PAM */
+#endif /* !USE_PAM */
 #endif /* !DCE_PASSWD */
 #endif /* !VMS */
 
@@ -1744,7 +1747,7 @@ krb_check_password(struct passwd *pwd, char *pass)
 
 extern krb5_error_code xlock_prompter(krb5_context, void *, const char *,
 				      const char *, int, krb5_prompt []);
-	
+
 static int
 krb_check_password(char *user, char *pass)
 {
@@ -1769,7 +1772,7 @@ krb_check_password(char *user, char *pass)
 
 	if (krb5_valid)
 		code = krb5_parse_name(kcontext, user, &me);
-	
+
 	if (! krb5_valid || (krb5_valid && code)) {
 		if ((code = krb5_cc_default(kcontext, &ccache))) {
 			com_err(ProgramName, code, "while getting default "
@@ -1792,7 +1795,7 @@ krb_check_password(char *user, char *pass)
 	/*
 	 * Set all of our various init_creds options
 	 */
-	
+
 	option = 0;
 	krb5_appdefault_boolean(kcontext, "xlock",
 				krb5_princ_realm(context, me), "forwardable",
@@ -1801,7 +1804,7 @@ krb_check_password(char *user, char *pass)
 
 	krb5_appdefault_string(kcontext, "xlock", krb5_princ_realm(context, me),
 			       "default_lifetime", "", &lifetimestr);
-	
+
 	if (lifetimestr && *lifetimestr) {
 		code = krb5_string_to_deltat(lifetimestr, &lifetime);
 		if (code == 0)
@@ -1840,7 +1843,7 @@ krb_check_password(char *user, char *pass)
 	 * Since the verification has succeeded, a failure at this point
 	 * will still result in returning a True.
 	 */
-	
+
 	if (!ccache && (code = krb5_cc_default(kcontext, &ccache)))
 		com_err(ProgramName, code, "while retrieving default "
 			"credential cache");
@@ -1848,7 +1851,7 @@ krb_check_password(char *user, char *pass)
 	if (!code && (code = krb5_cc_initialize(kcontext, ccache, me)))
 		com_err(ProgramName, code, "while initializing credential "
 			"cache");
-	
+
 	if (!code && (code = krb5_cc_store_cred(kcontext, ccache, &my_creds)))
 		com_err(ProgramName, code, "while storing credentials");
 
@@ -1985,7 +1988,7 @@ set_multiple(int uid)
 			if (pw->pw_uid != uid)
 				continue;
 #ifdef HAVE_SHADOW
-/*- 
+/*-
  * PURIFY on Solaris 2 reports a 1024 byte memory leak on the following line
  * if using NIS compatibility mode, and is internal to libc.so */
 			if ((spw = getspnam(pw->pw_name)) != NULL) {
@@ -2126,7 +2129,7 @@ void
 initPasswd(void)
 {
 	getUserName();
-#if !defined( ultrix ) && !defined( DCE_PASSWD ) && !defined( PAM )
+#if !defined( ultrix ) && !defined( DCE_PASSWD ) && !defined( USE_PAM )
 	if (!nolock && !inroot && !inwindow && grabmouse) {
 #ifdef BSD_AUTH
 		struct passwd *pwd = getpwnam(user);
@@ -2154,7 +2157,7 @@ initPasswd(void)
 #endif
 #endif /* !BSD_AUTH */
 	}
-#endif /* !ultrix && !DCE_PASSWD && !PAM */
+#endif /* !ultrix && !DCE_PASSWD && !USE_PAM */
 #ifdef DCE_PASSWD
 	initDCE();
 #endif
@@ -2205,7 +2208,7 @@ getCryptedXlockGroupPasswds()
 		else {
 
 #ifdef HAVE_SHADOW
-/*- 
+/*-
  * PURIFY on Solaris 2 reports a 1024 byte memory leak on the following line
  * if using NIS compatibility mode, and is internal to libc.so */
 			if ((spw = getspnam(pw->pw_name)) != NULL) {
@@ -2264,6 +2267,8 @@ int checkGroupXlockPasswds(char *buffer)
 
 #ifdef PASSWD_HELPER_PROGRAM
 #include <signal.h>
+#include <sys/types.h>
+#include <sys/wait.h>
 
 static int
 run_helper(const char *user, const char *pass)
