@@ -16,7 +16,7 @@ static const char sccsid[] = "@(#)resource.c	4.08 98/08/04 xlockmore";
  * 02-Dec-03: Jouk Jansen <joukj@hrem.stm.tudelft.nl>
  *            On OpenVMS when TCPIP is switched off gethostname does not
  *            work, in that case LIB$GETSYI to get the DECNET nodename.
- * 19-Jun-98: batchcount depreciated.  Use count instead.  batchcount still
+ * 19-Jun-98: batchcount deprecated.  Use count instead.  batchcount still
  *            works for commandline.
  * 01-May-97: Matthew Rench <mdrench@mtu.edu>
  *            Added DPMS options.
@@ -161,12 +161,13 @@ static int  descr();
 # ifdef AIXV3
 #  define DEF_FONT	"fixed"
 # else /* !AIXV3 */
-#  define DEF_FONT	"-b&h-lucida-medium-r-normal-sans-24-*-*-*-*-*-iso8859-1"
+#  define DEF_FONT	"-*-helvetica-medium-r-*-*-24-*-*-*-*-*-*"
 # endif /* !AIXV3 */
 #endif
-#define DEF_PLANFONT     "-adobe-courier-medium-r-*-*-14-*-*-*-m-*-iso8859-1"
+#define DEF_PLANFONT     "-*-fixed-medium-r-*-*-14-*-*-*-*-*-*"
 #ifdef USE_MB
-# define DEF_FONTSET	DEF_FONT ## ",-*-*-medium-r-normal--24-*"
+# define DEF_FONTSET	DEF_FONT ",-*-*-medium-r-normal--24-*"
+# define DEF_PLANFONTSET DEF_PLANFONT ",-*-*-medium-r-normal--14-*"
 #endif /* USE MB */
 #define DEF_BG		"White"
 #define DEF_FG		"Black"
@@ -376,6 +377,7 @@ static XrmOptionDescRec genTable[] =
 	{(char *) "-planfont", (char *) ".planfont", XrmoptionSepArg, (caddr_t) NULL},
 #ifdef USE_MB
 	{(char *) "-fontset", (char *) ".fontset", XrmoptionSepArg, (caddr_t) NULL},
+	{(char *) "-planfontset", (char *) ".planfontset", XrmoptionSepArg, (caddr_t) NULL},
 #endif
 	{(char *) "-bg", (char *) ".background", XrmoptionSepArg, (caddr_t) NULL},
 	{(char *) "-fg", (char *) ".foreground", XrmoptionSepArg, (caddr_t) NULL},
@@ -545,7 +547,7 @@ static OptionStruct opDesc[] =
 	{(char *) "-parent", (char *) "parent window id (for inwindow)"},
 {(char *) "-name resourcename", (char *) "class name to use for resources (default is XLock)"},
 	{(char *) "-delay usecs", (char *) "microsecond delay between screen updates"},
-	{(char *) "-batchcount num", (char *) "number of things per batch (depreciated)"},
+	{(char *) "-batchcount num", (char *) "number of things per batch (deprecated)"},
 	{(char *) "-count num", (char *) "number of things per batch"},
 	{(char *) "-cycles num", (char *) "number of cycles per batch"},
 	{(char *) "-size num", (char *) "size of a unit in a mode, default is 0"},
@@ -602,6 +604,7 @@ static OptionStruct opDesc[] =
 #endif
 #ifdef USE_MB
 	{(char *) "-fontset fontsetname", (char *) "fontset to use for Xmb..."},
+	{(char *) "-planfontset fontsetname", (char *) "fontset to use for Xmb..."},
 #endif
 	{(char *) "-bg color", (char *) "background color to use for password prompt"},
 	{(char *) "-fg color", (char *) "foreground color to use for password prompt"},
@@ -752,6 +755,7 @@ int         dpmsoff;
 
 #ifdef USE_MB
 char       *fontsetname;
+char       *planfontsetname;
 
 #endif
 char       *background;
@@ -844,127 +848,128 @@ Bool        vtlock_restore;
 
 static argtype genvars[] =
 {
-	{(caddr_t *) & erasemodename, (char *) "erasemode", (char *) "EraseMode", (char *) "", t_String},
-	{(caddr_t *) & erasedelay, (char *) "erasedelay", (char *) "EraseDelay", (char *) DEF_ERASEDELAY, t_Int},
-	{(caddr_t *) & erasetime, (char *) "erasetime", (char *) "EraseTime", (char *) DEF_ERASETIME, t_Int},
-	{(caddr_t *) & allowaccess, (char *) "allowaccess", (char *) "AllowAccess", (char *) "off", t_Bool},
+	{(void *) & erasemodename, (char *) "erasemode", (char *) "EraseMode", (char *) "", t_String},
+	{(void *) & erasedelay, (char *) "erasedelay", (char *) "EraseDelay", (char *) DEF_ERASEDELAY, t_Int},
+	{(void *) & erasetime, (char *) "erasetime", (char *) "EraseTime", (char *) DEF_ERASETIME, t_Int},
+	{(void *) & allowaccess, (char *) "allowaccess", (char *) "AllowAccess", (char *) "off", t_Bool},
 #ifndef ALWAYS_ALLOW_ROOT
-	{(caddr_t *) & allowroot, (char *) "allowroot", (char *) "AllowRoot", (char *) "off", t_Bool},
+	{(void *) & allowroot, (char *) "allowroot", (char *) "AllowRoot", (char *) "off", t_Bool},
 #endif
-	{(caddr_t *) & debug, (char *) "debug", (char *) "Debug", (char *) "off", t_Bool},
-	{(caddr_t *) & description, (char *) "description", (char *) "Description", (char *) "on", t_Bool},
-	{(caddr_t *) & echokeys, (char *) "echokeys", (char *) "EchoKeys", (char *) "off", t_Bool},
-	{(caddr_t *) & echokey, (char *) "echokey", (char *) "EchoKey", (char *) "?", t_String},
-    {(caddr_t *) & enablesaver, (char *) "enablesaver", (char *) "EnableSaver", (char *) "off", t_Bool},
-	{(caddr_t *) & resetsaver, (char *) "resetsaver", (char *) "ResetSaver", (char *) "on", t_Bool},
-	{(caddr_t *) & grabmouse, (char *) "grabmouse", (char *) "GrabMouse", (char *) "on", t_Bool},
-	{(caddr_t *) & grabserver, (char *) "grabserver", (char *) "GrabServer", (char *) "off", t_Bool},
-	{(caddr_t *) & hide, (char *) "hide", (char *) "Hide", (char *) "on", t_Bool},
-	{(caddr_t *) & install, (char *) "install", (char *) "Install", (char *) "on", t_Bool},
-    {(caddr_t *) & mousemotion, (char *) "mousemotion", (char *) "MouseMotion", (char *) "off", t_Bool},
-	{(caddr_t *) & mono, (char *) "mono", (char *) "Mono", (char *) "off", t_Bool},
-	{(caddr_t *) & sound, (char *) "sound", (char *) "Sound", (char *) "off", t_Bool},
+	{(void *) & debug, (char *) "debug", (char *) "Debug", (char *) "off", t_Bool},
+	{(void *) & description, (char *) "description", (char *) "Description", (char *) "on", t_Bool},
+	{(void *) & echokeys, (char *) "echokeys", (char *) "EchoKeys", (char *) "off", t_Bool},
+	{(void *) & echokey, (char *) "echokey", (char *) "EchoKey", (char *) "?", t_String},
+	{(void *) & enablesaver, (char *) "enablesaver", (char *) "EnableSaver", (char *) "off", t_Bool},
+	{(void *) & resetsaver, (char *) "resetsaver", (char *) "ResetSaver", (char *) "on", t_Bool},
+	{(void *) & grabmouse, (char *) "grabmouse", (char *) "GrabMouse", (char *) "on", t_Bool},
+	{(void *) & grabserver, (char *) "grabserver", (char *) "GrabServer", (char *) "off", t_Bool},
+	{(void *) & hide, (char *) "hide", (char *) "Hide", (char *) "on", t_Bool},
+	{(void *) & install, (char *) "install", (char *) "Install", (char *) "on", t_Bool},
+	{(void *) & mousemotion, (char *) "mousemotion", (char *) "MouseMotion", (char *) "off", t_Bool},
+	{(void *) & mono, (char *) "mono", (char *) "Mono", (char *) "off", t_Bool},
+	{(void *) & sound, (char *) "sound", (char *) "Sound", (char *) "off", t_Bool},
 #ifdef USE_GL
-	{(caddr_t *) & showfps, (char *) "showfps", (char *) "ShowFps", (char *) "off", t_Bool},
-	{(caddr_t *) & fpsTop, (char *) "fpstop", (char *) "FpsTop", (char *) "on", t_Bool},
-	{(caddr_t *) & fpsfontname, (char *) "fpsfont", (char *) "FpsFont", (char *) DEF_FONT, t_String},
+	{(void *) & showfps, (char *) "showfps", (char *) "ShowFps", (char *) "off", t_Bool},
+	{(void *) & fpsTop, (char *) "fpstop", (char *) "FpsTop", (char *) "on", t_Bool},
+	{(void *) & fpsfontname, (char *) "fpsfont", (char *) "FpsFont", (char *) DEF_FONT, t_String},
 #endif
-    {(caddr_t *) & timeelapsed, (char *) "timeelapsed", (char *) "TimeElapsed", (char *) "off", t_Bool},
-	{(caddr_t *) & usefirst, (char *) "usefirst", (char *) "UseFirst", (char *) "on", t_Bool},
-	{(caddr_t *) & verbose, (char *) "verbose", (char *) "Verbose", (char *) "off", t_Bool},
-	{(caddr_t *) & visualname, (char *) "visual", (char *) "Visual", (char *) "", t_String},
-	{(caddr_t *) & nicelevel, (char *) "nice", (char *) "Nice", (char *) DEF_NICE, t_Int},
-   {(caddr_t *) & lockdelay, (char *) "lockdelay", (char *) "LockDelay", (char *) DEF_LOCKDELAY, t_Int},
-	{(caddr_t *) & timeout, (char *) "timeout", (char *) "Timeout", (char *) DEF_TIMEOUT, t_Int},
-	{(caddr_t *) & fontname, (char *) "font", (char *) "Font", (char *) DEF_FONT, t_String},
-{(caddr_t *) & planfontname, (char *) "planfont", (char *) "PlanFont", (char *) DEF_PLANFONT, t_String},
+	{(void *) & timeelapsed, (char *) "timeelapsed", (char *) "TimeElapsed", (char *) "off", t_Bool},
+	{(void *) & usefirst, (char *) "usefirst", (char *) "UseFirst", (char *) "on", t_Bool},
+	{(void *) & verbose, (char *) "verbose", (char *) "Verbose", (char *) "off", t_Bool},
+	{(void *) & visualname, (char *) "visual", (char *) "Visual", (char *) "", t_String},
+	{(void *) & nicelevel, (char *) "nice", (char *) "Nice", (char *) DEF_NICE, t_Int},
+	{(void *) & lockdelay, (char *) "lockdelay", (char *) "LockDelay", (char *) DEF_LOCKDELAY, t_Int},
+	{(void *) & timeout, (char *) "timeout", (char *) "Timeout", (char *) DEF_TIMEOUT, t_Int},
+	{(void *) & fontname, (char *) "font", (char *) "Font", (char *) DEF_FONT, t_String},
+	{(void *) & planfontname, (char *) "planfont", (char *) "PlanFont", (char *) DEF_PLANFONT, t_String},
 #ifdef USE_MB
-    {(caddr_t *) & fontsetname, (char *) "fontset", (char *) "FontSet", (char *) DEF_FONTSET, t_String},
+	{(void *) & fontsetname, (char *) "fontset", (char *) "FontSet", (char *) DEF_FONTSET, t_String},
+	{(void *) & planfontsetname, (char *) "planfontset", (char *) "PlanFontSet", (char *) DEF_PLANFONTSET, t_String},
 #endif
-    {(caddr_t *) & background, (char *) "background", (char *) "Background", (char *) DEF_BG, t_String},
-    {(caddr_t *) & foreground, (char *) "foreground", (char *) "Foreground", (char *) DEF_FG, t_String},
-	{(caddr_t *) & text_user, (char *) "username", (char *) "Username", (char *) DEF_NAME, t_String},
-	{(caddr_t *) & text_pass, (char *) "password", (char *) "Password", (char *) DEF_PASS, t_String},
+	{(void *) & background, (char *) "background", (char *) "Background", (char *) DEF_BG, t_String},
+	{(void *) & foreground, (char *) "foreground", (char *) "Foreground", (char *) DEF_FG, t_String},
+	{(void *) & text_user, (char *) "username", (char *) "Username", (char *) DEF_NAME, t_String},
+	{(void *) & text_pass, (char *) "password", (char *) "Password", (char *) DEF_PASS, t_String},
 #ifdef GLOBAL_UNLOCK
-	{(caddr_t *) & text_guser, (char *) "globaluser", (char *) "GlobalUser", (char *) DEF_GUSER, t_String},
+	{(void *) & text_guser, (char *) "globaluser", (char *) "GlobalUser", (char *) DEF_GUSER, t_String},
 #endif
 
 #ifdef SAFEWORD
-	{(caddr_t *) & text_dpass, (char *) "dynpass", (char *) "Dynpass", (char *) DEF_DPASS, t_String},
-	{(caddr_t *) & text_fpass, (char *) "fixpass", (char *) "Fixpass", (char *) DEF_FPASS, t_String},
-   {(caddr_t *) & text_chall, (char *) "challenge", (char *) "Challenge", (char *) DEF_CHALL, t_String},
+	{(void *) & text_dpass, (char *) "dynpass", (char *) "Dynpass", (char *) DEF_DPASS, t_String},
+	{(void *) & text_fpass, (char *) "fixpass", (char *) "Fixpass", (char *) DEF_FPASS, t_String},
+	{(void *) & text_chall, (char *) "challenge", (char *) "Challenge", (char *) DEF_CHALL, t_String},
 #endif
-	{(caddr_t *) & text_info, (char *) "info", (char *) "Info", (char *) DEF_INFO, t_String},
+	{(void *) & text_info, (char *) "info", (char *) "Info", (char *) DEF_INFO, t_String},
 #ifdef HAVE_KRB5
-	{(caddr_t *) & text_krbinfo, (char *) "kerberosinfo", (char *) "KerberosInfo", (char *) DEF_KRBINFO, t_String},
+	{(void *) & text_krbinfo, (char *) "kerberosinfo", (char *) "KerberosInfo", (char *) DEF_KRBINFO, t_String},
 #endif /* HAVE_KRB5 */
-     {(caddr_t *) & text_valid, (char *) "validate", (char *) "Validate", (char *) DEF_VALID, t_String},
-   {(caddr_t *) & text_invalid, (char *) "invalid", (char *) "Invalid", (char *) DEF_INVALID, t_String},
-   {(caddr_t *) & text_invalidCapsLock, (char *) "invalidCapsLock", (char *) "InvalidCapsLock", (char *) DEF_INVALIDCAPSLOCK, t_String},
-   {(caddr_t *) & failed_attempt, (char *) "attempt", (char *) "Attempt", (char *) DEF_COUNT_FAILED, t_String},
-   {(caddr_t *) & failed_attempts, (char *) "attempts", (char *) "Attempts", (char *) DEF_COUNTS_FAILED, t_String},
-    {(caddr_t *) & geometry, (char *) "geometry", (char *) "Geometry", (char *) DEF_GEOMETRY, t_String},
-	{(caddr_t *) & icongeometry, (char *) "icongeometry", (char *) "IconGeometry", (char *) DEF_ICONGEOMETRY, t_String},
+	{(void *) & text_valid, (char *) "validate", (char *) "Validate", (char *) DEF_VALID, t_String},
+	{(void *) & text_invalid, (char *) "invalid", (char *) "Invalid", (char *) DEF_INVALID, t_String},
+	{(void *) & text_invalidCapsLock, (char *) "invalidCapsLock", (char *) "InvalidCapsLock", (char *) DEF_INVALIDCAPSLOCK, t_String},
+	{(void *) & failed_attempt, (char *) "attempt", (char *) "Attempt", (char *) DEF_COUNT_FAILED, t_String},
+	{(void *) & failed_attempts, (char *) "attempts", (char *) "Attempts", (char *) DEF_COUNTS_FAILED, t_String},
+	{(void *) & geometry, (char *) "geometry", (char *) "Geometry", (char *) DEF_GEOMETRY, t_String},
+	{(void *) & icongeometry, (char *) "icongeometry", (char *) "IconGeometry", (char *) DEF_ICONGEOMETRY, t_String},
 #ifdef FX
-	{(caddr_t *) & glgeometry, (char *) "glgeometry", (char *) "GLGeometry", (char *) DEF_GLGEOMETRY, t_String},
+	{(void *) & glgeometry, (char *) "glgeometry", (char *) "GLGeometry", (char *) DEF_GLGEOMETRY, t_String},
 #endif
-	{(caddr_t *) & wireframe, (char *) "wireframe", (char *) "WireFrame", (char *) "off", t_Bool},
+	{(void *) & wireframe, (char *) "wireframe", (char *) "WireFrame", (char *) "off", t_Bool},
 
-	{(caddr_t *) & use3d, (char *) "use3d", (char *) "Use3D", (char *) "off", t_Bool},
-	{(caddr_t *) & delta3d, (char *) "delta3d", (char *) "Delta3D", (char *) DEF_DELTA3D, t_Float},
-	{(caddr_t *) & none3d, (char *) "none3d", (char *) "None3D", (char *) DEF_NONE3D, t_String},
-	{(caddr_t *) & right3d, (char *) "right3d", (char *) "Right3D", (char *) DEF_RIGHT3D, t_String},
-	{(caddr_t *) & left3d, (char *) "left3d", (char *) "Left3D", (char *) DEF_LEFT3D, t_String},
-	{(caddr_t *) & both3d, (char *) "both3d", (char *) "Both3D", (char *) DEF_BOTH3D, t_String},
+	{(void *) & use3d, (char *) "use3d", (char *) "Use3D", (char *) "off", t_Bool},
+	{(void *) & delta3d, (char *) "delta3d", (char *) "Delta3D", (char *) DEF_DELTA3D, t_Float},
+	{(void *) & none3d, (char *) "none3d", (char *) "None3D", (char *) DEF_NONE3D, t_String},
+	{(void *) & right3d, (char *) "right3d", (char *) "Right3D", (char *) DEF_RIGHT3D, t_String},
+	{(void *) & left3d, (char *) "left3d", (char *) "Left3D", (char *) DEF_LEFT3D, t_String},
+	{(void *) & both3d, (char *) "both3d", (char *) "Both3D", (char *) DEF_BOTH3D, t_String},
 
-	{(caddr_t *) & program, (char *) "program", (char *) "Program", (char *) DEF_PROGRAM, t_String},
-	{(caddr_t *) & messagesfile, (char *) "messagesfile", (char *) "Messagesfile", (char *) DEF_MESSAGESFILE, t_String},
-	{(caddr_t *) & messagefile, (char *) "messagefile", (char *) "Messagefile", (char *) DEF_MESSAGEFILE, t_String},
-	{(caddr_t *) & message, (char *) "message", (char *) "Message", (char *) DEF_MESSAGE, t_String},
-	{(caddr_t *) & messagefontname, (char *) "messagefont", (char *) "MessageFont", (char *) DEF_MESSAGEFONT, t_String},
+	{(void *) & program, (char *) "program", (char *) "Program", (char *) DEF_PROGRAM, t_String},
+	{(void *) & messagesfile, (char *) "messagesfile", (char *) "Messagesfile", (char *) DEF_MESSAGESFILE, t_String},
+	{(void *) & messagefile, (char *) "messagefile", (char *) "Messagefile", (char *) DEF_MESSAGEFILE, t_String},
+	{(void *) & message, (char *) "message", (char *) "Message", (char *) DEF_MESSAGE, t_String},
+	{(void *) & messagefontname, (char *) "messagefont", (char *) "MessageFont", (char *) DEF_MESSAGEFONT, t_String},
 #if 0
-   {(caddr_t *) & neighbors, (char *) "neighbors", (char *) "Neighbors", (char *) DEF_NEIGHBORS, t_Int},
-	{(caddr_t *) & mouse, (char *) "mouse", (char *) "Mouse", (char *) DEF_MOUSE, t_Bool},
+	{(void *) & neighbors, (char *) "neighbors", (char *) "Neighbors", (char *) DEF_NEIGHBORS, t_Int},
+	{(void *) & mouse, (char *) "mouse", (char *) "Mouse", (char *) DEF_MOUSE, t_Bool},
 #endif
 
 #if defined( USE_XLOCKRC ) || defined( FALLBACK_XLOCKRC )
-	{(caddr_t *) & cpasswd, (char *) "cpasswd", (char *) "cpasswd", (char *) "", t_String},
+	{(void *) & cpasswd, (char *) "cpasswd", (char *) "cpasswd", (char *) "", t_String},
 #endif
 #ifdef USE_AUTO_LOGOUT
-	{(caddr_t *) & logoutAuto, (char *) "logoutAuto", (char *) "logoutAuto", (char *) DEF_AUTO_LOGOUT, t_Int},
+	{(void *) & logoutAuto, (char *) "logoutAuto", (char *) "logoutAuto", (char *) DEF_AUTO_LOGOUT, t_Int},
 #endif
 #ifdef USE_BUTTON_LOGOUT
-	{(caddr_t *) & logoutButton, (char *) "logoutButton", (char *) "LogoutButton", (char *) DEF_BUTTON_LOGOUT, t_Int},
-	{(caddr_t *) & logoutButtonLabel, (char *) "logoutButtonLabel",
+	{(void *) & logoutButton, (char *) "logoutButton", (char *) "LogoutButton", (char *) DEF_BUTTON_LOGOUT, t_Int},
+	{(void *) & logoutButtonLabel, (char *) "logoutButtonLabel",
 	 "LogoutButtonLabel", (char *) DEF_BTN_LABEL, t_String},
-	{(caddr_t *) & logoutButtonHelp, (char *) "logoutButtonHelp",
+	{(void *) & logoutButtonHelp, (char *) "logoutButtonHelp",
 	 "LogoutButtonHelp", (char *) DEF_BTN_HELP, t_String},
-	{(caddr_t *) & logoutFailedString, (char *) "logoutFailedString",
+	{(void *) & logoutFailedString, (char *) "logoutFailedString",
 	 "LogoutFailedString", (char *) DEF_FAIL, t_String},
 #endif
 #ifdef USE_SOUND
-	{(caddr_t *) & locksound, (char *) "locksound", (char *) "LockSound", (char *) DEF_LOCKSOUND, t_String},
-	{(caddr_t *) & infosound, (char *) "infosound", (char *) "InfoSound", (char *) DEF_INFOSOUND, t_String},
-	{(caddr_t *) & validsound, (char *) "validsound", (char *) "ValidSound", (char *) DEF_VALIDSOUND, t_String},
-	{(caddr_t *) & invalidsound, (char *) "invalidsound", (char *) "InvalidSound", (char *) DEF_INVALIDSOUND, t_String},
+	{(void *) & locksound, (char *) "locksound", (char *) "LockSound", (char *) DEF_LOCKSOUND, t_String},
+	{(void *) & infosound, (char *) "infosound", (char *) "InfoSound", (char *) DEF_INFOSOUND, t_String},
+	{(void *) & validsound, (char *) "validsound", (char *) "ValidSound", (char *) DEF_VALIDSOUND, t_String},
+	{(void *) & invalidsound, (char *) "invalidsound", (char *) "InvalidSound", (char *) DEF_INVALIDSOUND, t_String},
 #endif
-	{(caddr_t *) & startCmd, (char *) "startCmd", (char *) "StartCmd", (char *) "", t_String},
-	{(caddr_t *) & endCmd, (char *) "endCmd", (char *) "EndCmd", (char *) "", t_String},
+	{(void *) & startCmd, (char *) "startCmd", (char *) "StartCmd", (char *) "", t_String},
+	{(void *) & endCmd, (char *) "endCmd", (char *) "EndCmd", (char *) "", t_String},
 #ifndef VMS
-	{(caddr_t *) & pipepassCmd, (char *) "pipepassCmd", (char *) "PipePassCmd", (char *) "", t_String},
+	{(void *) & pipepassCmd, (char *) "pipepassCmd", (char *) "PipePassCmd", (char *) "", t_String},
 #endif
-	{(caddr_t *) & logoutCmd, (char *) "logoutCmd", (char *) "LogoutCmd", (char *) "", t_String},
+	{(void *) & logoutCmd, (char *) "logoutCmd", (char *) "LogoutCmd", (char *) "", t_String},
 #ifdef USE_DPMS
-	{(caddr_t *) & dpmsstandby, (char *) "dpmsstandby", (char *) "DPMSStandby", (char *) DEF_DPMSSTANDBY, t_Int},
-	{(caddr_t *) & dpmssuspend, (char *) "dpmssuspend", (char *) "DPMSSuspend", (char *) DEF_DPMSSUSPEND, t_Int},
-	{(caddr_t *) & dpmsoff, (char *) "dpmsoff", (char *) "DPMSOff", (char *) DEF_DPMSOFF, t_Int},
+	{(void *) & dpmsstandby, (char *) "dpmsstandby", (char *) "DPMSStandby", (char *) DEF_DPMSSTANDBY, t_Int},
+	{(void *) & dpmssuspend, (char *) "dpmssuspend", (char *) "DPMSSuspend", (char *) DEF_DPMSSUSPEND, t_Int},
+	{(void *) & dpmsoff, (char *) "dpmsoff", (char *) "DPMSOff", (char *) DEF_DPMSOFF, t_Int},
 #endif
 
-	{(caddr_t *) & mailCmd, (char *) "mailCmd", (char *) "MailCmd", (char *) DEF_MAILAPP, t_String},
-     	{(caddr_t *) & mailIcon, (char *) "mailIcon", (char *) "MailIcon", (char *) DEF_MAILAPP, t_String},
-	{(caddr_t *) & nomailIcon, (char *) "nomailIcon", (char *) "NomailIcon", (char *) DEF_MAILAPP, t_String},
+	{(void *) & mailCmd, (char *) "mailCmd", (char *) "MailCmd", (char *) DEF_MAILAPP, t_String},
+     	{(void *) & mailIcon, (char *) "mailIcon", (char *) "MailIcon", (char *) DEF_MAILAPP, t_String},
+	{(void *) & nomailIcon, (char *) "nomailIcon", (char *) "NomailIcon", (char *) DEF_MAILAPP, t_String},
 #ifdef USE_VTLOCK
-	{(caddr_t *) & vtlockres, (char *) "vtlock", (char *) "VtLock", DEF_VTLOCK, t_String},
+	{(void *) & vtlockres, (char *) "vtlock", (char *) "VtLock", DEF_VTLOCK, t_String},
 #endif
 #if 0
     /* These resources require special handling.  They must be examined
@@ -972,10 +977,10 @@ static argtype genvars[] =
      * calls to GetResource(), so they should not be evaluated again here.
      * For example, X-terminals need this special treatment.
      */
-	{(caddr_t *) & nolock, (char *) "nolock", (char *) "NoLock", (char *) "off", t_Bool},
-	{(caddr_t *) & inwindow, (char *) "inwindow", (char *) "InWindow", (char *) "off", t_Bool},
-	{(caddr_t *) & inroot, (char *) "inroot", (char *) "InRoot", (char *) "off", t_Bool},
-	{(caddr_t *) & remote, (char *) "remote", (char *) "Remote", (char *) "off", t_Bool},
+	{(void *) & nolock, (char *) "nolock", (char *) "NoLock", (char *) "off", t_Bool},
+	{(void *) & inwindow, (char *) "inwindow", (char *) "InWindow", (char *) "off", t_Bool},
+	{(void *) & inroot, (char *) "inroot", (char *) "InRoot", (char *) "off", t_Bool},
+	{(void *) & remote, (char *) "remote", (char *) "Remote", (char *) "off", t_Bool},
 #endif
 };
 
@@ -983,13 +988,13 @@ static argtype genvars[] =
 
 static argtype modevars[] =
 {
-	{(caddr_t *) & delay, (char *) "delay", (char *) "Delay", (char *) DEF_DELAY, t_Int},
-	{(caddr_t *) & count, (char *) "count", (char *) "Count", (char *) DEF_COUNT, t_Int},
-	{(caddr_t *) & cycles, (char *) "cycles", (char *) "Cycles", (char *) DEF_CYCLES, t_Int},
-	{(caddr_t *) & size, (char *) "size", (char *) "Size", (char *) DEF_SIZE, t_Int},
-	{(caddr_t *) & ncolors, (char *) "ncolors", (char *) "NColors", (char *) DEF_NCOLORS, t_Int},
-	{(caddr_t *) & saturation, (char *) "saturation", (char *) "Saturation", (char *) DEF_SATURATION, t_Float},
-	{(caddr_t *) & bitmap, (char *) "bitmap", (char *) "Bitmap", (char *) DEF_BITMAP, t_String}
+	{(void *) & delay, (char *) "delay", (char *) "Delay", (char *) DEF_DELAY, t_Int},
+	{(void *) & count, (char *) "count", (char *) "Count", (char *) DEF_COUNT, t_Int},
+	{(void *) & cycles, (char *) "cycles", (char *) "Cycles", (char *) DEF_CYCLES, t_Int},
+	{(void *) & size, (char *) "size", (char *) "Size", (char *) DEF_SIZE, t_Int},
+	{(void *) & ncolors, (char *) "ncolors", (char *) "NColors", (char *) DEF_NCOLORS, t_Int},
+	{(void *) & saturation, (char *) "saturation", (char *) "Saturation", (char *) DEF_SATURATION, t_Float},
+	{(void *) & bitmap, (char *) "bitmap", (char *) "Bitmap", (char *) DEF_BITMAP, t_String}
 };
 
 #define NMODEARGS (sizeof modevars / sizeof modevars[0])
@@ -1112,7 +1117,7 @@ checkSpecialArgs(int argc, char **argv)
 			Version();
 #ifdef CHECK_OLD_ARGS
 		{
-			static char *depreciated_args[] =
+			static char *deprecated_args[] =
 	{(char *) "-v", (char *) "-imagefile", (char *) "-mfont",
 	 (char *) "-rule3d", (char *) "-life3dfile",
 	 (char *) "-mouse", (char *) "-shift", (char *) "-tshift"};
@@ -1123,9 +1128,9 @@ checkSpecialArgs(int argc, char **argv)
 			int         j;
 
 			for (j = 0; j < (int) ((sizeof current_args) / sizeof (*current_args)); j++)
-				if (!strcmp(argv[i], depreciated_args[j])) {
-					(void) printf("%s depreciated, use %s\n",
-					depreciated_args[j], current_args[j]);
+				if (!strcmp(argv[i], deprecated_args[j])) {
+					(void) printf("%s deprecated, use %s\n",
+					deprecated_args[j], current_args[j]);
 					exit(0);
 				}
 		}
@@ -1183,7 +1188,7 @@ static void
 GetResource(XrmDatabase database,
 	   const char *parentName, const char *parentClassName,
      const char *name, const char *className, int valueType, char *def,
-     caddr_t * valuep)
+     void* valuep)
 {
 	char       *type;
 	XrmValue    value;
@@ -1209,7 +1214,7 @@ GetResource(XrmDatabase database,
 	} else {
 		string = def;
 		if (!string || !*string) {
-			*valuep = (caddr_t) NULL;
+			*((caddr_t *) valuep) = NULL;
 			return;
 		}
 		len = strlen(string);
@@ -1466,17 +1471,11 @@ openDisplay(Display ** displayp)
 	displayname = DisplayString(*displayp);
 }
 
-static void
-checkDisplay(void)
-{
-	char       *buf;
-	struct hostent *host;
-
+#ifdef SOLARIS2
+extern struct hostent *gethostbyname(const char *);
+#else
 #if defined(__cplusplus) || defined(c_plusplus)		/* !__bsdi__ */
 /* #include <netdb.h> */
-#ifdef SunCplusplus
-	extern struct hostent *gethostbyname(const char *);
-#else
 #if !HAVE_GETHOSTNAME
 #if 0
 	extern int  gethostname(char *, size_t);
@@ -1492,6 +1491,11 @@ extern int  gethostname(char *, size_t);
 #endif
 #endif
 #endif
+static void
+checkDisplay(void)
+{
+	char       *buf;
+	struct hostent *host;
 
 	/*
 	 * only restrict access to other displays if we are locking and if the
@@ -1687,11 +1691,12 @@ getAppResources(char *homeenv, char **custom, XrmDatabase * RDB,
 	XrmDatabase applicationDB = (XrmDatabase) NULL;
 
 	env = getenv("XFILESEARCHPATH");
-	applicationDB = parsefilepath(env ? env : (char *) DEF_FILESEARCHPATH,
-				      "app-defaults", classname, *custom);
+	applicationDB = parsefilepath(
+		((env == NULL) ? (char *) DEF_FILESEARCHPATH : env),
+		"app-defaults", classname, *custom);
 
 	XrmParseCommand(&cmdlineDB, cmdlineTable, cmdlineEntries, ProgramName,
-			argc, argv);
+		argc, argv);
 
 	userpath = getenv("XUSERFILESEARCHPATH");
 	if (!userpath) {
@@ -1743,16 +1748,16 @@ getAppResources(char *homeenv, char **custom, XrmDatabase * RDB,
 			parentSet = True;
 	}
 	GetResource(*RDB, ProgramName, classname, "nolock", "NoLock", t_Bool,
-		    (char *) "off", (caddr_t *) & nolock);
+		    (char *) "off", (void *) & nolock);
 	GetResource(*RDB, ProgramName, classname, "inwindow", "InWindow", t_Bool,
-		    (char *) "off", (caddr_t *) & inwindow);
+		    (char *) "off", (void *) & inwindow);
 	GetResource(*RDB, ProgramName, classname, "inroot", "InRoot", t_Bool,
-		    (char *) "off", (caddr_t *) & inroot);
+		    (char *) "off", (void *) & inroot);
 	GetResource(*RDB, ProgramName, classname, "remote", "Remote", t_Bool,
-		    (char *) "off", (caddr_t *) & remote);
+		    (char *) "off", (void *) & remote);
 #ifdef USE_DTSAVER
 	GetResource(*RDB, ProgramName, classname, "dtsaver", "DtSaver", t_Bool,
-		    (char *) "off", (caddr_t *) & dtsaver);
+		    (char *) "off", (void *) & dtsaver);
 	if (dtsaver) {
 		inroot = False;
 		inwindow = True;
@@ -1867,7 +1872,7 @@ getResources(Display ** displayp, int argc, char **argv)
 	(void) XrmMergeDatabases(generalDB, &RDB);
 
 	GetResource(RDB, ProgramName, classname, "mode", "Mode", t_String,
-		    (char *) DEF_MODE, (caddr_t *) & mode);
+		    (char *) DEF_MODE, (void *) & mode);
 
 	XrmParseCommand(&modeDB, modeTable, modeEntries, ProgramName, &argc, argv);
 	(void) XrmMergeDatabases(modeDB, &RDB);
@@ -1911,8 +1916,9 @@ getResources(Display ** displayp, int argc, char **argv)
 
 	for (i = 0; i < (int) NGENARGS; i++) {
 		GetResource(RDB, ProgramName, classname,
-			    genvars[i].name, genvars[i].classname,
-			    genvars[i].type, genvars[i].def, genvars[i].var);
+			genvars[i].name, genvars[i].classname,
+			genvars[i].type, genvars[i].def,
+			(void *) genvars[i].var);
 	}
 
 #ifdef USE_VTLOCK
@@ -1970,28 +1976,33 @@ getResources(Display ** displayp, int argc, char **argv)
 			switch (modevars[j].type) {
 				case t_String:
 					buf = (char *) malloc(strlen(*((char **) p)) + 1);
-					(void) sprintf(buf, "%s", *((char **) p));
+					(void) sprintf(buf, "%s",
+						*((char **) p));
 					break;
 				case t_Float:
 					buf = (char *) malloc(16);
-					(void) sprintf(buf, "%g", *((float *) p));
+					(void) sprintf(buf, "%g",
+						*((float *) p));
 					break;
 				case t_Int:
 					buf = (char *) malloc(16);
-					(void) sprintf(buf, "%d", *((int *) p));
+					(void) sprintf(buf,
+						"%d", *((int *) p));
 					break;
 				case t_Bool:
 					buf = (char *) malloc(6);
-					(void) sprintf(buf, "%s", *((int *) p) ? "True" : "False");
+					(void) sprintf(buf, "%s",
+						*((int *) p) ? "True" : "False");
 					break;
 			}
 			GetResource(RDB, modename, modeclassname,
-				    modevars[j].name, modevars[j].classname,
-				    modevars[j].type, buf, (caddr_t *) p);
+				modevars[j].name, modevars[j].classname,
+				modevars[j].type, buf, (void *) p);
 			if (!strcmp(mode, LockProcs[i].cmdline_arg)) {
 				GetResource(RDB, modename, modeclassname,
 				     modevars[j].name, modevars[j].classname,
-				     modevars[j].type, buf, modevars[j].var);
+				     modevars[j].type, buf,
+				     (void *) modevars[j].var);
 			}
 			if (buf) {
 				free(buf);
@@ -2004,7 +2015,7 @@ getResources(Display ** displayp, int argc, char **argv)
 		for (j = 0; j < ms->numvarsdesc; j++) {
 			GetResource(RDB, modename, modeclassname,
 				v[j].name, v[j].classname,
-				v[j].type, v[j].def, v[j].var);
+				v[j].type, v[j].def, (void *) v[j].var);
 		}
 	}
 
